Learn R Programming

rWind (version 0.4.1)

rWind-package: Download, edit and include wind data in ecological and evolutionary analysis

Description

rWind contain tools for downloading, editing and transforming wind data from Global Forecast System (GFS). It also allows to use wind data to compute the minimum cost path from wind speed and direction to perform connectivity analysis.

Arguments

Details

The complete list of functions can be displayed with library(help = rWind). For more information, please check: http://allthiswasfield.blogspot.com.es/