wind.dl downloads wind data from the Global Forecast System (GFS) of the USA's National Weather Service (NWS) (https://www.ncdc.noaa.gov/data-access/model-data/model-datasets/global-forcast-system-gfs). Wind data are taken from NOAA/NCEP Global Forecast System (GFS) Atmospheric Model colection. Geospatial resolution is 0.5 degrees (approximately 50 km), and wind is calculated for Earth surface, at 10 m. More metadata information: http://oos.soest.hawaii.edu/erddap/info/NCEP_Global_Best/index.html
Usage
wind.dl(yyyy, mm, dd, tt, lon1, lon2, lat1, lat2, type="read-data")
Arguments
yyyy
Selected year from 2011 to current.
mm
Selected month
dd
Selected day
tt
Selected time. There are currently several options at the GFS database: 00:00 - 03:00 - 06:00 - 09:00 - 12:00 - 15:00 - 18:00 - 21:00 (UTC)
lon1
Western longitude
lon2
Eastern longitude
lat1
Southern latitude
lat2
Northern latitude
type
Output type. "read-data" is selected by default, creating an R object. If you choose "csv", wind.dl create a a CSV file in your work directory named "wind_yyyy_mm_dd_tt.csv".
Value
A data.frame or .csv file with U and V vector components for each coordenate in the study area defined by lon1/lon2 and lat1/lat2 and a column with time and date.
Details
The output type is determined by type="csv" or type="read-data". If type="csv" is selected, the function creates a "wind_yyyy_mm_dd_tt.csv" file that is downloaded at the work directory. If type="read-data" is selected, an R object (data.frame) is created.