# NOT RUN {
# First, you should create an empty list to store all the data
# wind_series<- list()
# Then, you can use a wind.dl inside a for-in loop to download and store wind data of
# the January 3rd 2015 at several hours around New Zealand.
# t<-c(00 , 03 , 06 , 09 , 12 , 15 , 18 , 21)
# for (tt in 1:8){
# w<-wind.dl(2015,1,3,t[tt],164,179,-48,-33)
# wind_series[[tt]]<-w
# }
data(wind_series)
# Finally, you can implement wind.mean and wind.fit to compute the average of all winds
# datasets in the list:
wind_average<- wind.mean(wind_series)
# wind.fit(wind_average)
# }
Run the code above in your browser using DataLab