Learn R Programming

rWind (version 0.4.1)

wind_data: Wind data example

Description

This is an example of wind data obtained with wind.dl function for the Iberian Peninsula coordenates on 12/February/2015 at 00:00 (UTC)

Arguments

Format

A data.frame with 652 observations on the following 5 variables:

list("time (UTC)")

a factor with selected time of wind data

list("latitude (degrees_north)")

a factor with latitude values

list("longitude (degrees_east)")

a factor with longitude values

list("ugrd10m (m s-1)")

a factor with U component of wind data

list("vgrd10m (m s-1)")

a factor with V component of wind data

Details

This data set is the result of:

wind_data<-wind.dl(2015,2,12,0,-10,5,35,45)

References

http://oos.soest.hawaii.edu/erddap/info/NCEP_Global_Best/index.html

Examples

Run this code
# NOT RUN {
data(wind_data)
str(wind_data)
head(wind_data)

# }

Run the code above in your browser using DataLab