Learn R Programming

rWind (version 0.4.1)

wind_series: Wind series example

Description

This is an example of a wind series data obtained with a loop and wind.dl function for New Zealand area on 3/January/2015 at all the available times: 00:00 - 03:00 - 06:00 - 09:00 - 12:00 - 15:00 - 18:00 - 21:00 (UTC)

Arguments

Format

The format is a list of 8 data.frame. Each data.frame contain 652 observations on the following 5 variables:

list("time (UTC)")

a factor with selected time of wind data

list("latitude (degrees_north)")

a factor with latitude values

list("longitude (degrees_east)")

a factor with longitude values

list("ugrd10m (m s-1)")

a factor with U component of wind data

list("vgrd10m (m s-1)")

a factor with V component of wind data

Details

You can find the code used to build this data-set in the help file of wind.mean function

References

http://oos.soest.hawaii.edu/erddap/info/NCEP_Global_Best/index.html

Examples

Run this code
# NOT RUN {
data(wind_series)
str(wind_series)
wind_average<- wind.mean(wind_series)

# }

Run the code above in your browser using DataLab