powered by
This is an example of wind data obtained with wind.dl function for the Iberian Peninsula coordetanes on 12/February/2015 at 00:00 (UTC)
data("wind_data")
A data.frame with 652 observations on the following 5 variables:
time (UTC)
a factor with selected time of wind data
latitude (degrees_north)
a factor with latitude values
longitude (degrees_east)
a factor with longitude values
ugrd10m (m s-1)
a factor with U component of wind data
vgrd10m (m s-1)
a factor with V component of wind data
This data set is the result of:
wind_data<-wind.dl(2015,2,12,0,-10,5,35,45)
http://oos.soest.hawaii.edu/erddap/info/NCEP_Global_Best/index.html
# NOT RUN { data(wind_data) str(wind_data) head(wind_data) # }
Run the code above in your browser using DataLab